@@ -5,8 +5,8 @@ from __future__ import unicode_literals
 # This is an end-to-end example of the flaky package in action. Consider it
 # a live tutorial, showing the various features in action.
 
-from unittest import TestCase, expectedFailure, skip
 from box.test.flaky import flaky
+from box.test.flaky.utils import TestCase, expectedFailure, skip
 
 
 class ExampleTests(TestCase):
