@@ -1,9 +1,9 @@
 # coding: utf-8
 
 from __future__ import unicode_literals
-from unittest import TestCase
 from box.test.flaky.flaky_decorator import flaky
 from box.test.flaky.names import FlakyNames
+from box.test.flaky.utils import TestCase
 
 
 class TestFlakyDecorator(TestCase):
@@ -11,16 +11,20 @@ class TestFlakyDecorator(TestCase):
         super(TestFlakyDecorator, self).setUp()
 
     def test_flaky_raises_for_non_positive_min_passes(self):
-        with self.assertRaises(ValueError):
-            def test_something():
-                pass
-            flaky(min_passes=0)(test_something)
+        def test_something():
+            pass
+        self.assertRaises(
+            ValueError,
+            lambda: flaky(min_passes=0)(test_something),
+        )
 
     def test_flaky_raises_for_max_runs_less_than_min_passes(self):
-        with self.assertRaises(ValueError):
-            def test_something():
-                pass
-            flaky(max_runs=2, min_passes=3)(test_something)
+        def test_something():
+            pass
+        self.assertRaises(
+            ValueError,
+            lambda: flaky(max_runs=2, min_passes=3)(test_something),
+        )
 
     def test_flaky_adds_flaky_attributes_to_test_method(self):
         min_passes = 4
@@ -30,13 +34,13 @@ class TestFlakyDecorator(TestCase):
         def test_something():
             pass
 
-        flaky_attribute = {
-            attr: getattr(
+        flaky_attribute = dict((
+            (attr, getattr(
                 test_something,
                 attr,
                 None
-            ) for attr in FlakyNames()
-        }
+            )) for attr in FlakyNames()
+        ))
 
         self.assertIsNotNone(flaky_attribute)
         self.assertDictContainsSubset(
